pub enum InputType<'a> {
InputObject(&'a SchemaInputObject<'a>),
Scalar(&'a SchemaScalar<'a>),
Enum(&'a SchemaEnum<'a>),
}Expand description
An input type enum that represents all possible GraphQL definition types that an argument or input object field may accept.
Variants
Implementations
Sourceimpl<'a> InputType<'a>
impl<'a> InputType<'a>
pub fn name(&self) -> &str
pub fn named_type(&self) -> SchemaType<'a>