pub struct SchemaInputObject<'a> {
pub name: &'a str,
pub fields: HashMap<&'a str, SchemaInputField<'a>, DefaultHashBuilder, &'a Bump>,
}Expand description
An Input Object type definition.
Inputs, such as arguments, may sometimes be nested and accept objects that must adhere to the shape of an Input Object definition. This is often used to represent more complex inputs. Reference
Fields
name: &'a strfields: HashMap<&'a str, SchemaInputField<'a>, DefaultHashBuilder, &'a Bump>Implementations
Sourceimpl<'a> SchemaInputObject<'a>
impl<'a> SchemaInputObject<'a>
pub fn new(ctx: &'a ASTContext, name: &'a str) -> Self
pub fn add_field(&mut self, _ctx: &'a ASTContext, field: SchemaInputField<'a>)