SchemaSuperType

Trait SchemaSuperType 

pub trait SchemaSuperType<'a>: Sized {
    // Required method
    fn is_sub_type(&self, subtype: SchemaType<'a>) -> bool;
}
Generic trait for any schema type that may be a super type of other types

Required Methods

fn is_sub_type(&self, subtype: SchemaType<'a>) -> bool

Checks whether a given type is a sub type of the current super type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors